app/soc/logic/models/host.py
changeset 1085 0afbdd0905ef
parent 1062 f7ee38ebfe1c
child 1140 a8eaea0b268d
--- a/app/soc/logic/models/host.py	Fri Jan 30 17:23:19 2009 +0000
+++ b/app/soc/logic/models/host.py	Fri Jan 30 17:38:28 2009 +0000
@@ -44,14 +44,14 @@
 
 
   def _onCreate(self, entity):
     """Marks the Sponsor for this Host as active it's state is new.
     """
 
     sponsor_entity = entity.scope
 
-    if sponsor_entity.state == 'new':
+    if sponsor_entity.status == 'new':
       # this sponsor is new so mark as active
-      fields = {'state' : 'active'}
+      fields = {'status' : 'active'}
       sponsor_logic.logic.updateEntityProperties(sponsor_entity, fields)
 
     # call super
@@ -44,14 +44,14 @@
 
   def _onCreate(self, entity):
-    """Marks the Sponsor for this Host as active it's state is new.
+    """Marks the Sponsor for this Host as active it's status is new.
     """
 